# AkriML
Data exploration and curation methods for large, high-dimensional datasets.




## Development

`./.pylintrc` is included for pylint config.

### Pre-commit hooks

#### Prerequisites (One-time setup)

```commandline
pip install pre-commit  # Install the pre-commit pip package
# Verify (hidden) file named `./.pre-commit-config.yaml` exists
pre-commit install
```